<?php
/**
 * @version   1.7 February 19, 2015
 * @author    RocketTheme, LLC http://www.rockettheme.com
 * @copyright Copyright (C) 2007 - 2015 RocketTheme, LLC
 * @license   http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
 */
/*
Plugin Name: RokStock
Plugin URI: http://www.rockettheme.com
Description: RokStock, is an Ajax-powered stocks widget for your site. It has been finely tuned to give stocks character such as a coloured line graph, coloured indexes, draggable indexes, tooltips and much more.
Author: RocketTheme, LLC
Version: 1.7
Author URI: http://www.rockettheme.com
License: http://www.gnu.org/licenses/gpl-2.0.html GNU/GPLv2 only
*/

// Define Directory Separator

if (!defined('DS')) {
	define('DS', DIRECTORY_SEPARATOR);
}

// Globals

global $rokstock_plugin_path, $rokstock_plugin_url, $browser_platform, $browser_name, $browser_version;
if(!is_multisite()) {
    $rokstock_plugin_path = dirname($plugin);
} else {
	if(!empty($network_plugin)) {
		$rokstock_plugin_path = dirname($network_plugin);
	} else {
		$rokstock_plugin_path = dirname($plugin);
	}
}
$rokstock_plugin_url = WP_PLUGIN_URL.'/'.basename($rokstock_plugin_path);

require(dirname(__FILE__).DS.'rokbrowsercheck.php');

$browser_check = new RokBrowserCheck;
$browser_platform = $browser_check->platform;

// Define Cache Dir
if (!defined('ROKSTOCK_CACHE')) {
	define('ROKSTOCK_CACHE', $rokstock_plugin_path.'/cache');
}

require_once(dirname(__FILE__).DS.'googlestock.class.php');

class RokStock {

	// RocketTheme RokStock Plugin
	// Port by Jakub Baran

	// Initialise Default Options
	function rokstock_defaults() {

		$options = array(
			'default_stocks' => '.DJI, .INX, .IXIC',
			'user_interaction' => '1',
			'store_cookie' => '1',
			'store_time' => '30',
			'externals' => '1',
			'show_main_chart' => '1',
			'show_tooltips' => '1',
			'time_display' => '12'
		);
		
		add_option('rokstock_options', $options);
	}
	
	// Add FrontEnd Styles
	function rokstock_styles() {
		global $rokstock_plugin_url;
		// Enqueue Style 
		wp_enqueue_style('rokstock_css', $rokstock_plugin_url.'/rokstock.css');
	}

	// Add FrontEnd Scripts
	function rokstock_scripts() {
		global $rokstock_plugin_url;
		
		$option = get_option('rokstock_options');
		if(!is_admin() && $option['user_interaction'] == '1') {
			// Enqueue JS
			wp_enqueue_script('rokstock_js', $rokstock_plugin_url.'/tmpl/js/rokstock.js');
		}
	}
	
	// Inline Head Script
	function rokstock_head() {
        if(!is_admin()){
            
            $option = get_option('rokstock_options');

            if (!defined('ROKSTOCK_JS')) {
                $save_cookie = ($option['store_cookie'] == '1') ? 1 : 0;
                $duration_cookie = $option['store_time'];
                $externals = ($option['externals'] == '1') ? 1 : 0;
                $show_main_chart = ($option['show_main_chart'] == '1') ? 1 : 0;
                $show_tooltips = ($option['show_tooltips'] == '1') ? 1 : 0;
                $url = get_bloginfo('wpurl').'/wp-admin/admin-ajax.php?action=rokstock';

                $js_init = "window.addEvent('domready', function() {
                    new RokStock({
                        detailURL: '{$url}',
                        cookie: {$save_cookie},
                        cookieDuration: {$duration_cookie},
                        externalLinks: {$externals},
                        mainChart: {$show_main_chart},
                        toolTips: {$show_tooltips}
                    });
                });";

                echo "<script type=\"text/javascript\">\n/* <![CDATA[ */\n$js_init\n/* ]]> */\n</script>\n";

                define('ROKSTOCK_JS',1);
            }
        }
	}
	
	// Set init cookie
	function rokstock_setcookie() {
		$option = get_option('rokstock_options');
		$stocklist = $option['default_stocks'];
		$save_cookie = ($option['store_cookie'] == '1') ? true : false;
		$duration_cookie = $option['store_time'];
		$cookie_name = "rokstock_tickers";
		
		if ($save_cookie) {
			if (!isset($_COOKIE[$cookie_name])) setcookie($cookie_name, urlencode($stocklist), time()+60*60*24*$duration_cookie, '/', false);
		}		
	}
	
	// RokStock Main
	function rokstock_render() {
		global $rokstock_plugin_path, $rokstock_plugin_url;
		
		$option = get_option('rokstock_options');
		$stocklist = $option['default_stocks'];
		$default_cookie = ".DJI%2C+.INX%2C+.IXIC";
		$cookie_name = "rokstock_tickers";
		
		$show_main_chart = ($option['show_main_chart'] == '1') ? true : false;
		$images = $rokstock_plugin_url.'/images/';
		$output = "";
		$output_type = "default";
		
		$save_cookie = ($option['store_cookie'] == '1') ? true : false;
		$duration_cookie = $option['store_time'];
		
		if ($save_cookie) {
			if (isset($_COOKIE[$cookie_name])) $stocklist = urldecode($_COOKIE[$cookie_name]);
		}
		
		if (isset($_GET['values'])) $stocklist = $_GET['values'];
		
		if (isset($_GET['output_type']) && isset($_GET['chart_values']) && $_GET['output_type'] == 'chart') {
			$output_type = "chart";
			$chart_values = $_GET['chart_values'];
		} else if (isset($_GET['output_type']) && isset($_GET['detail_values']) && $_GET['output_type'] == 'detail') {
			$output_type = "detail";
			$detail_values = $_GET['detail_values'];
		} else if (isset($_GET['output_type']) && isset($_GET['details_value']) && $_GET['output_type'] == 'moredetails') {
			$output_type = "moredetails";
			$detail_values = $_GET['details_value'];
		}
		
		switch($output_type) {
			case "chart":
				if(file_exists(TEMPLATEPATH.DS.'html'.DS.'plugins'.DS.'wp_rokstock'.DS.'chart.php')) :	
			  		require(TEMPLATEPATH.DS.'html'.DS.'plugins'.DS.'wp_rokstock'.DS.'chart.php');
			  	else :
	  		  		require($rokstock_plugin_path.DS.'tmpl'.DS.'chart.php'); 
	  		  	endif;
				break;
			case "detail":
				$tickers = RokStock::getStock($detail_values, $option);
				if (!$tickers) : echo "false";
				else :
					if(file_exists(TEMPLATEPATH.DS.'html'.DS.'plugins'.DS.'wp_rokstock'.DS.'detail.php')) :	
				  		require(TEMPLATEPATH.DS.'html'.DS.'plugins'.DS.'wp_rokstock'.DS.'detail.php');
				  	else :
		  		  		require($rokstock_plugin_path.DS.'tmpl'.DS.'detail.php'); 
		  		  	endif;
				endif;
				break;
			case "moredetails":
				$tickers = RokStock::getStock($detail_values, $option);
				if (!$tickers) : echo "false";
				else :
					if(file_exists(TEMPLATEPATH.DS.'html'.DS.'plugins'.DS.'wp_rokstock'.DS.'moredetails.php')) :	
				  		require(TEMPLATEPATH.DS.'html'.DS.'plugins'.DS.'wp_rokstock'.DS.'moredetails.php');
				  	else :
		  		  		require($rokstock_plugin_path.DS.'tmpl'.DS.'moredetails.php'); 
		  		  	endif;
				endif;
				break;
			case "default": default: 
				$tickers = RokStock::getStock($stocklist, $option);
				if(file_exists(TEMPLATEPATH.DS.'html'.DS.'plugins'.DS.'wp_rokstock'.DS.'default.php')) :	
			  		require(TEMPLATEPATH.DS.'html'.DS.'plugins'.DS.'wp_rokstock'.DS.'default.php');
			  	else :
	  		  		require($rokstock_plugin_path.DS.'tmpl'.DS.'default.php'); 
	  		  	endif;		
		}
		
		if (isset($_GET['action']) && $_GET['action'] == 'rokstock') die();
		
	}
	
	function rokstock_shortcode($atts, $content = null) {
		return ROKSTOCK::rokstock_render();
	}
	
	function getStock($stocks, $options) {
	 	$gstock = new googleStock(ROKSTOCK_CACHE);
		$output = $gstock->makeRequest($stocks);
		
		return $output;
	}
	
	// Plugin settings button
	function rokstock_admin() {
		add_plugins_page('RokStock Settings', 'RokStock', 'activate_plugins', 'rokstock-settings', array('RokStock', 'rokstock_settings'));  
	}
	
	// Add Admin Styles
	function rokstock_adminstyles() {
		global $rokstock_plugin_url, $pagenow;
		// Enqueue Style 
		if($pagenow == 'plugins.php' && $_GET['page'] == 'rokstock-settings') :
			wp_enqueue_style('rokstockadmin_css', $rokstock_plugin_url.'/admin/rokstock.css');
		endif;
	}
	
	// Register Settings	
	function rokstock_regsettings() {
		register_setting('rokstock_registered', 'rokstock_options');
	}
	
	// Settings Page
	function rokstock_settings() {
	
		$option = get_option('rokstock_options');
		
		if(isset($_GET['settings-updated']) && $_GET['settings-updated'] == 'true') { ?><div id="message" class="updated fade"><p><?php _e('RokStock settings saved.', 'rokstock'); ?></p></div><?php } ?>
		
		<div class="wrap" id="rokstock-settings">
		
			<div id="icon-options-rokstock" class="icon32"><br /></div>
			<h2><?php _e('RokStock Settings', 'rokstock'); ?></h2>
			<div class="clear"></div>
			
			<form method="post" action="options.php">
				<?php settings_fields('rokstock_registered'); ?>
				<table class="widefat fixed rokplugin" cellspacing="0">
					<thead>
						<tr>
							<th class="manage-column column-title desc" scope="col">
								<?php _e('Option Name', 'rokstock'); ?>
							</th>
							<th class="manage-column column-title desc" scope="col">
								<?php _e('Value', 'rokstock'); ?>
							</th>
						</tr>
					</thead>
					<tfoot>
						<tr>
							<th>
								<a href="http://rockettheme.com" target="_blank" id="rtlogo"></a>				
							</th>
							<th>
								<input type="submit" class="button-primary" value="<?php _e('Save Changes', 'rokstock'); ?>" />
							</th>
						</tr>
					</tfoot>
					<tbody>
						<tr>
							<td>
								<strong><?php _e('Default Stocks', 'rokstock'); ?></strong>
							</td>
							<td>
								<input type="text" size="50" maxlength="255" name="rokstock_options[default_stocks]" value="<?php echo $option['default_stocks']; ?>" />
							</td>
						</tr>
						<tr class="alternate">
							<td>
								<strong><?php _e('User interaction', 'rokstock'); ?></strong>
							</td>
							<td>
								<input id="user_interaction1" type="radio" <?php if ($option['user_interaction'] == '1') : ?>checked="checked"<?php endif; ?> value="1" name="rokstock_options[user_interaction]"/>
								<label for="user_interaction1"><?php _e('Yes', 'rokstock'); ?></label>&nbsp;&nbsp;&nbsp;&nbsp;
								<input id="user_interaction2" type="radio" <?php if ($option['user_interaction'] == '0') : ?>checked="checked"<?php endif; ?> value="0" name="rokstock_options[user_interaction]"/>
								<label for="user_interaction2"><?php _e('No', 'rokstock'); ?></label>
							</td>
						</tr>
						<tr>
							<td>
								<strong><?php _e('Save/Restore status', 'rokstock'); ?></strong>
							</td>
							<td>
								<input id="store_cookie1" type="radio" <?php if ($option['store_cookie'] == '1') : ?>checked="checked"<?php endif; ?> value="1" name="rokstock_options[store_cookie]"/>
								<label for="store_cookie1"><?php _e('Yes', 'rokstock'); ?></label>&nbsp;&nbsp;&nbsp;&nbsp;
								<input id="store_cookie2" type="radio" <?php if ($option['store_cookie'] == '0') : ?>checked="checked"<?php endif; ?> value="0" name="rokstock_options[store_cookie]"/>
								<label for="store_cookie2"><?php _e('No', 'rokstock'); ?></label>
							</td>
						</tr>
						<tr class="alternate">
							<td>
								<strong><?php _e('Store duration (days)', 'rokstock'); ?></strong>
							</td>
							<td>
								<input type="text" size="50" maxlength="255" name="rokstock_options[store_time]" value="<?php echo $option['store_time']; ?>" />
							</td>
						</tr>
						<tr>
							<td>
								<strong><?php _e('Open links in new page', 'rokstock'); ?></strong>
							</td>
							<td>
								<input id="externals1" type="radio" <?php if ($option['externals'] == '1') : ?>checked="checked"<?php endif; ?> value="1" name="rokstock_options[externals]"/>
								<label for="externals1"><?php _e('Yes', 'rokstock'); ?></label>&nbsp;&nbsp;&nbsp;&nbsp;
								<input id="externals2" type="radio" <?php if ($option['externals'] == '0') : ?>checked="checked"<?php endif; ?> value="0" name="rokstock_options[externals]"/>
								<label for="externals2"><?php _e('No', 'rokstock'); ?></label>
							</td>
						</tr>
						<tr class="alternate">
							<td>
								<strong><?php _e('Show main chart', 'rokstock'); ?></strong>
							</td>
							<td>
								<input id="show_main_chart1" type="radio" <?php if ($option['show_main_chart'] == '1') : ?>checked="checked"<?php endif; ?> value="1" name="rokstock_options[show_main_chart]"/>
								<label for="show_main_chart1"><?php _e('Yes', 'rokstock'); ?></label>&nbsp;&nbsp;&nbsp;&nbsp;
								<input id="show_main_chart2" type="radio" <?php if ($option['show_main_chart'] == '0') : ?>checked="checked"<?php endif; ?> value="0" name="rokstock_options[show_main_chart]"/>
								<label for="show_main_chart2"><?php _e('No', 'rokstock'); ?></label>
							</td>
						</tr>
						<tr>
							<td>
								<strong><?php _e('Tooltips details', 'rokstock'); ?></strong>
							</td>
							<td>
								<input id="show_tooltips1" type="radio" <?php if ($option['show_tooltips'] == '1') : ?>checked="checked"<?php endif; ?> value="1" name="rokstock_options[show_tooltips]"/>
								<label for="show_tooltips1"><?php _e('Yes', 'rokstock'); ?></label>&nbsp;&nbsp;&nbsp;&nbsp;
								<input id="show_tooltips2" type="radio" <?php if ($option['show_tooltips'] == '0') : ?>checked="checked"<?php endif; ?> value="0" name="rokstock_options[show_tooltips]"/>
								<label for="show_tooltips2"><?php _e('No', 'rokstock'); ?></label>
							</td>
						</tr>
						<tr class="alternate">
							<td>
								<strong><?php _e('Show main chart', 'rokstock'); ?></strong>
							</td>
							<td>
								<input id="time_display1" type="radio" <?php if ($option['time_display'] == '12') : ?>checked="checked"<?php endif; ?> value="12" name="rokstock_options[time_display]"/>
								<label for="time_display1"><?php _e('12h', 'rokstock'); ?></label>&nbsp;&nbsp;&nbsp;&nbsp;
								<input id="time_display2" type="radio" <?php if ($option['time_display'] == '24') : ?>checked="checked"<?php endif; ?> value="24" name="rokstock_options[time_display]"/>
								<label for="time_display2"><?php _e('24h', 'rokstock'); ?></label>
							</td>
						</tr>
					</tbody>
				</table>
			</form>
			
		</div>
		
		<?php
			
	}

}

// Widget
class RokStockWidget extends WP_Widget {

	// RocketTheme RokStock Widget
	// Port by Jakub Baran

    static $plugin_path;
    static $plugin_url;

    var $short_name = 'widget-rokstock';
    var $long_name = 'RokStock';
    var $description = 'RocketTheme RokStock Widget';
    var $css_classname = 'widget_rokstock';
    var $width = 200;
    var $height = 400;

    var $_defaults = array(
        'title' => ''				
    );

    function init() {
    	global $browser_platform;
    	
    	// Don't show RokStock on iPhone or Android platform
    	if($browser_platform != 'iphone' || $browser_platform != 'android') :
	        register_widget("RokStockWidget");
    	endif;
    }
	
    function render($args, $instance) {
        global $rokstock_plugin_path, $rokstock_plugin_url;
        
        ob_start();
        
        // Before Widget
        echo $args['before_widget'];
        
        // Widget Title
        if($instance['title'] != '')
 		echo $args['before_title'] . $instance['title'] . $args['after_title'];
 		
 		// Render RokStock

		do_shortcode('[rokstock]');
              
        // After Widget
        echo $args['after_widget'];
        
        echo ob_get_clean();
    }
    
    function form($instance) {
    	global $rokstock_plugin_path, $rokstock_plugin_url;
        $defaults = $this->_defaults;
  		$instance = wp_parse_args((array) $instance, $defaults);
        foreach ($instance as $variable => $value)
        {
            $$variable = self::_cleanOutputVariable($variable, $value);
            $instance[$variable] = $$variable;
        }
        $this->_values = $instance;
        
        ob_start();
        
        ?>
		
		<!-- Begin RokStock Widget Admin -->
		
		<div class="rokstock-admin-wrapper">
			<p>
		        <label for="<?php echo $this->get_field_id('title'); ?>">
		        	<?php _e('Title:', 'rokstock'); ?>
		        </label>
		    	<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $instance['title']; ?>" />
	    	</p>
		</div>
		
		<!-- End RokStock Widget Admin -->
	
		<?php
	
        echo ob_get_clean();
    }
    
    /********** Bellow here should not need to be changed ***********/

    function __construct() {
        if (empty($this->short_name) || empty($this->long_name)) {
            die("A widget must have a valid type and classname defined");
        }
        $widget_options = array('classname' => $this->css_classname, 'description' => __($this->description));
        $control_options = array('width' => $this->width, 'height' => $this->height);
        parent::__construct($this->short_name, $this->long_name, $widget_options, $control_options);
    }

    function _cleanOutputVariable($variable, $value) {
        if (is_string($value)) {
        	return htmlspecialchars($value);
        }
        elseif (is_array($value)) {
            foreach ($value as $subvariable => $subvalue) {
                $value[$subvariable] = self::_cleanOutputVariable($subvariable, $subvalue);
            }
            return $value;
        }
        return $value;
    }

    function _cleanInputVariable($variable, $value) {
        if (is_string($value)) {
            return stripslashes($value);
        }
        elseif (is_array($value)) {
            foreach ($value as $subvariable => $subvalue) {
                $value[$subvariable] = self::_cleanInputVariable($subvariable, $subvalue);
            }
            return $value;
        }
        return $value;
    }

    function widget($args, $instance){
        global $gantry;
 		extract($args);
        $defaults = $this->_defaults;
        $instance = wp_parse_args((array) $instance, $defaults);
        foreach ($instance as $variable => $value)
        {
            $$variable = self::_cleanOutputVariable($variable, $value);
            $instance[$variable] = $$variable;
        }
        
        $this->render($args, $instance);
        
    }

}

RokStockWidget::$plugin_path = dirname($plugin);
RokStockWidget::$plugin_url = WP_PLUGIN_URL.'/'.basename(RokStockWidget::$plugin_path);

add_shortcode('rokstock', array('RokStock', 'rokstock_shortcode'));
add_action('admin_menu', array('RokStock', 'rokstock_admin'), 9);
add_action('admin_init', array('RokStock', 'rokstock_regsettings'));
add_action('admin_print_styles', array('RokStock', 'rokstock_adminstyles'));
add_action('init', array('RokStock', 'rokstock_defaults'));
add_action('init', array('RokStock', 'rokstock_setcookie'));
add_action('widgets_init', array('RokStockWidget', 'init'));
add_action('wp_print_styles', array('RokStock', 'rokstock_styles'));
add_action('wp_print_scripts', array('RokStock', 'rokstock_scripts'));
add_action('wp_head', array('RokStock', 'rokstock_head'));

// Add AJAX

add_action('wp_ajax_rokstock', array('RokStock', 'rokstock_render'));
add_action('wp_ajax_nopriv_rokstock', array('RokStock', 'rokstock_render'));

// Load Language

load_plugin_textdomain('rokstock', false, basename($rokstock_plugin_path).DS.'languages'.DS);

// MooTools Enqueue Script

add_action('init', 'rokstock_mootools_init', -50);

function rokstock_mootools_init(){
	global $rokstock_plugin_url;
    wp_register_script('mootools.js', $rokstock_plugin_url.'/tmpl/js/mootools.js');
	wp_enqueue_script('mootools.js');
}

?>